==> opentoutatice-ecm-platform-automation-4.4.31.2-sources.jar: fr/toutatice/ecm/platform/automation/comments/DeleteComment.java <==
/*
 * (C) Copyright 2014 Académie de Rennes (http://www.ac-rennes.fr/), OSIVIA (http://www.osivia.com) and others.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser General Public License
 * (LGPL) version 2.1 which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-2.1.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 *
 * Contributors:
 *   mberhaut1
 *    
 */
package fr.toutatice.ecm.platform.automation.comments;

import org.nuxeo.ecm.automation.core.Constants;
import org.nuxeo.ecm.automation.core.annotations.Operation;
import org.nuxeo.ecm.automation.core.annotations.OperationMethod;
import org.nuxeo.ecm.automation.core.annotations.Param;
import org.nuxeo.ecm.core.api.ClientException;
import org.nuxeo.ecm.core.api.DocumentModel;
import org.nuxeo.ecm.platform.comment.api.CommentableDocument;

@Operation(id = DeleteComment.ID, category = Constants.CAT_DOCUMENT, label = "DeleteCommentOfDocument", description = "Delete a comment of a (commentable) document")
public class DeleteComment {
	
public static final String ID = "Document.DeleteComment";

	@Param(name = "commentableDoc", required = true)
	protected DocumentModel document;
	
	@Param(name = "comment", required = true)
	protected DocumentModel comment;

	@OperationMethod
	public Object run() throws ClientException {
		
		if (document.hasFacet("Commentable")) {
			CommentableDocument commentableDoc = document.getAdapter(CommentableDocument.class);
			commentableDoc.removeComment(comment);
		}
		return document;
		
	}
}

==> opentoutatice-ecm-platform-automation-4.7.16-sources.jar: fr/toutatice/ecm/platform/automation/comments/DeleteComment.java <==
/*
 * (C) Copyright 2014 Académie de Rennes (http://www.ac-rennes.fr/), OSIVIA (http://www.osivia.com) and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser General Public License
 * (LGPL) version 2.1 which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-2.1.html
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * 
 * Contributors:
 * mberhaut1
 */
package fr.toutatice.ecm.platform.automation.comments;

import org.nuxeo.ecm.automation.core.Constants;
import org.nuxeo.ecm.automation.core.annotations.Operation;
import org.nuxeo.ecm.automation.core.annotations.OperationMethod;
import org.nuxeo.ecm.automation.core.annotations.Param;
import org.nuxeo.ecm.core.api.ClientException;
import org.nuxeo.ecm.core.api.DocumentModel;
import org.nuxeo.ecm.platform.comment.api.CommentableDocument;

@Operation(id = DeleteComment.ID, category = Constants.CAT_DOCUMENT, label = "DeleteCommentOfDocument",
        description = "Delete a comment of a (commentable) document")
public class DeleteComment {

    public static final String ID = "Document.DeleteComment";

    @Param(name = "commentableDoc", required = true)
    protected DocumentModel document;

    @Param(name = "comment", required = true)
    protected DocumentModel comment;

    @OperationMethod
    public Object run() throws ClientException {

        if (this.document.hasFacet("Commentable")) {
            CommentableDocument commentableDoc = this.document.getAdapter(CommentableDocument.class);
            commentableDoc.removeComment(this.comment);
        }
        return this.document;

    }
}
